import React, { useEffect, useState } from 'react'
import axios from 'axios'
import { Link, useParams } from 'react-router-dom'
import { API_BASE_URL } from '@/config'
import TagSearch from './TagSearch'
import SidebarComponent from './layout/SidebarComponent'

import type { Post, Tag } from '@/types'

type TagByCategory = { [key: string]: Tag[] }

type Props = { post: Post | null }


export default ({ post }: Props) => {
  const [tags, setTags] = useState<TagByCategory> ({ })

  const categoryNames: { [key: string]: string } = {
      general:    '一般',
      deerjikist: 'ニジラー',
      nico:       'ニコニコタグ' }

  useEffect (() => {
    if (!(post))
      return

    const fetchTags = async () => {
      const tagsTmp: TagByCategory = { }
      for (const tag of post.tags)
        {
          if (!(tag.category in tagsTmp))
            tagsTmp[tag.category] = []
          tagsTmp[tag.category].push (tag)
        }
      for (const cat of Object.keys (tagsTmp))
        tagsTmp[cat].sort ((tagA, tagB) => tagA.name < tagB.name ? -1 : 1)
      setTags (tagsTmp)
    }

    fetchTags ()
  }, [post])

  return (
      <SidebarComponent>
        <TagSearch />
        {['general', 'deerjikist', 'nico'].map (cat => cat in tags && (
            <>
              <h2>{categoryNames[cat]}</h2>
              <ul>
                {tags[cat].map (tag => (
                    <li key={tag.id} className="mb-2">
                      <Link to={`/posts?${ (new URLSearchParams ({ tags: tag.name })).toString () }`}
                            className="text-blue-600 hover:underline">
                        {tag.name}
                      </Link>
                    </li>))}
              </ul>
            </>))}
      </SidebarComponent>)
}
